import { LCDClient } from "@osmonauts/lcd";
import { setPaginationParams } from "@osmonauts/helpers";
export class LCDQueryClient extends LCDClient {
  constructor({
    restEndpoint
  }) {
    super({
      restEndpoint
    });
  }
  /* Accounts returns all the existing accounts
  
  Since: cosmos-sdk 0.43 */


  async accounts(params = {
    pagination: undefined
  }) {
    const options = {
      params: {}
    };

    if (typeof (params === null || params === void 0 ? void 0 : params.pagination) !== "undefined") {
      setPaginationParams(options, params.pagination);
    }

    const endpoint = `cosmos/auth/v1beta1/accounts`;
    return await this.request(endpoint, options);
  }
  /* Account returns account details based on address. */


  async account(params) {
    const endpoint = `cosmos/auth/v1beta1/accounts/${params.address}`;
    return await this.request(endpoint);
  }
  /* Params queries all parameters. */


  async params(_params = {}) {
    const endpoint = `cosmos/auth/v1beta1/params`;
    return await this.request(endpoint);
  }
  /* ModuleAccounts returns all the existing module accounts. */


  async moduleAccounts(_params = {}) {
    const endpoint = `cosmos/auth/v1beta1/module_accounts`;
    return await this.request(endpoint);
  }
  /* Bech32 queries bech32Prefix */


  async bech32Prefix(_params = {}) {
    const endpoint = `cosmos/auth/v1beta1/bech32`;
    return await this.request(endpoint);
  }
  /* AddressBytesToString converts Account Address bytes to string */


  async addressBytesToString(params) {
    const options = {
      params: {}
    };

    if (typeof (params === null || params === void 0 ? void 0 : params.addressBytes) !== "undefined") {
      options.params.address_bytes = params.addressBytes;
    }

    const endpoint = `cosmos/auth/v1beta1/bech32/${params.addressBytes}`;
    return await this.request(endpoint, options);
  }
  /* AddressStringToBytes converts Address string to bytes */


  async addressStringToBytes(params) {
    const options = {
      params: {}
    };

    if (typeof (params === null || params === void 0 ? void 0 : params.addressString) !== "undefined") {
      options.params.address_string = params.addressString;
    }

    const endpoint = `cosmos/auth/v1beta1/bech32/${params.addressString}`;
    return await this.request(endpoint, options);
  }

}