import { LCDClient } from "@osmonauts/lcd";
import { setPaginationParams } from "@osmonauts/helpers";
export class LCDQueryClient extends LCDClient {
  constructor({
    restEndpoint
  }) {
    super({
      restEndpoint
    });
  }
  /* Proposal queries proposal details based on ProposalID. */


  async proposal(params) {
    const options = {
      params: {}
    };

    if (typeof (params === null || params === void 0 ? void 0 : params.proposalId) !== "undefined") {
      options.params.proposal_id = params.proposalId;
    }

    const endpoint = `cosmos/gov/v1beta1/proposals/${params.proposalId}`;
    return await this.request(endpoint, options);
  }
  /* Proposals queries all proposals based on given status. */


  async proposals(params) {
    const options = {
      params: {}
    };

    if (typeof (params === null || params === void 0 ? void 0 : params.proposalStatus) !== "undefined") {
      options.params.proposal_status = params.proposalStatus;
    }

    if (typeof (params === null || params === void 0 ? void 0 : params.voter) !== "undefined") {
      options.params.voter = params.voter;
    }

    if (typeof (params === null || params === void 0 ? void 0 : params.depositor) !== "undefined") {
      options.params.depositor = params.depositor;
    }

    if (typeof (params === null || params === void 0 ? void 0 : params.pagination) !== "undefined") {
      setPaginationParams(options, params.pagination);
    }

    const endpoint = `cosmos/gov/v1beta1/proposals`;
    return await this.request(endpoint, options);
  }
  /* Vote queries voted information based on proposalID, voterAddr. */


  async vote(params) {
    const options = {
      params: {}
    };

    if (typeof (params === null || params === void 0 ? void 0 : params.proposalId) !== "undefined") {
      options.params.proposal_id = params.proposalId;
    }

    const endpoint = `cosmos/gov/v1beta1/proposals/${params.proposalId}votes/${params.voter}`;
    return await this.request(endpoint, options);
  }
  /* Votes queries votes of a given proposal. */


  async votes(params) {
    const options = {
      params: {}
    };

    if (typeof (params === null || params === void 0 ? void 0 : params.proposalId) !== "undefined") {
      options.params.proposal_id = params.proposalId;
    }

    if (typeof (params === null || params === void 0 ? void 0 : params.pagination) !== "undefined") {
      setPaginationParams(options, params.pagination);
    }

    const endpoint = `cosmos/gov/v1beta1/proposals/${params.proposalId}/votes`;
    return await this.request(endpoint, options);
  }
  /* Params queries all parameters of the gov module. */


  async params(params) {
    const options = {
      params: {}
    };

    if (typeof (params === null || params === void 0 ? void 0 : params.paramsType) !== "undefined") {
      options.params.params_type = params.paramsType;
    }

    const endpoint = `cosmos/gov/v1beta1/params/${params.paramsType}`;
    return await this.request(endpoint, options);
  }
  /* Deposit queries single deposit information based proposalID, depositAddr. */


  async deposit(params) {
    const options = {
      params: {}
    };

    if (typeof (params === null || params === void 0 ? void 0 : params.proposalId) !== "undefined") {
      options.params.proposal_id = params.proposalId;
    }

    const endpoint = `cosmos/gov/v1beta1/proposals/${params.proposalId}deposits/${params.depositor}`;
    return await this.request(endpoint, options);
  }
  /* Deposits queries all deposits of a single proposal. */


  async deposits(params) {
    const options = {
      params: {}
    };

    if (typeof (params === null || params === void 0 ? void 0 : params.proposalId) !== "undefined") {
      options.params.proposal_id = params.proposalId;
    }

    if (typeof (params === null || params === void 0 ? void 0 : params.pagination) !== "undefined") {
      setPaginationParams(options, params.pagination);
    }

    const endpoint = `cosmos/gov/v1beta1/proposals/${params.proposalId}/deposits`;
    return await this.request(endpoint, options);
  }
  /* TallyResult queries the tally of a proposal vote. */


  async tallyResult(params) {
    const options = {
      params: {}
    };

    if (typeof (params === null || params === void 0 ? void 0 : params.proposalId) !== "undefined") {
      options.params.proposal_id = params.proposalId;
    }

    const endpoint = `cosmos/gov/v1beta1/proposals/${params.proposalId}/tally`;
    return await this.request(endpoint, options);
  }

}